@@ -43,8 +43,9 @@ class garmintools_full():
 	"""
 	def __init__(self, parent = None, validate=False):
 		self.parent = parent
-		self.confdir = self.parent.conf.getValue("confdir")
-		self.tmpdir = self.parent.conf.getValue("tmpdir")
+		self.pytrainer_main = parent.pytrainer_main
+		self.confdir = self.pytrainer_main.profile.confdir
+		self.tmpdir = self.pytrainer_main.profile.tmpdir
 		# Tell garmintools where to save retrieved data from GPS device
 		os.environ['GARMIN_SAVE_RUNS']=self.tmpdir
 		self.data_path = os.path.dirname(__file__)
@@ -64,7 +65,7 @@ class garmintools_full():
 	def getConfValue(self, confVar):
 		info = XMLParser(self.data_path+"/conf.xml")
 		code = info.getValue("pytrainer-plugin","plugincode")
-		plugindir = self.parent.conf.getValue("plugindir")
+		plugindir = self.pytrainer_main.profile.plugindir
 		if not os.path.isfile(plugindir+"/"+code+"/conf.xml"):
 			value = None
 		else:
@@ -79,8 +80,8 @@ class garmintools_full():
 			numError = self.getDeviceInfo()
 			if numError >= 0:
 				#TODO Remove Zenity below
-				outgps = commands.getstatusoutput("garmin_save_runs | zenity --progress --pulsate --text='Loading Data' auto-close")
-				if outgps[0]==0: 
+				outgps = commands.getstatusoutput("garmin_save_runs -v| zenity --progress --pulsate --text='Loading Data' --auto-close")
+				if outgps[0]==0:
 					# now we should have a lot of gmn (binary) files under $GARMIN_SAVE_RUNS
 					foundFiles = self.searchFiles(self.tmpdir, "gmn")
 					logging.info("Retrieved "+str(len(foundFiles))+" entries from GPS device")
@@ -93,7 +94,7 @@ class garmintools_full():
 					if len(selectedFiles) > 0:
 						logging.info("Dumping "+str(len(selectedFiles))+" binary files found")
 						dumpFiles = self.dumpBinaries(selectedFiles)
-						self.listStringDBUTC = self.parent.parent.ddbb.select("records","date_time_utc")
+						self.listStringDBUTC = self.pytrainer_main.ddbb.select("records","date_time_utc")
 						if self.maxGap > 0:
 							logging.info("Starting import. Comparison will be made with "+str(self.maxGap)+" seconds interval")
 						else:
@@ -108,7 +109,7 @@ class garmintools_full():
 				if numError == -1:
 					os.popen("zenity --error --text='No Garmin device found\nCheck your configuration'");
 				elif numError == -2:
-					os.popen("zenity --error --text='Can not find garmintools binaries\nCheck your configuration'")			
+					os.popen("zenity --error --text='Can not find garmintools binaries\nCheck your configuration'")
 		else: #No garmin device found
 				#TODO Remove Zenity below
 				os.popen("zenity --error --text='Can not handle Garmin device (wrong module loaded)\nCheck your configuration'");
@@ -143,17 +144,23 @@ class garmintools_full():
 				#read file into string
 				with open(filename, 'r') as f:
 					xmlString = f.read()
+				# Double check encoding from dump files. ASCII?
+				# http://docs.python.org/library/stringio.html#module-cStringIO
 				fileString = StringIO.StringIO("<root>"+xmlString+"</root>")
 				#parse string as xml
-				tree = etree.parse(fileString)
-				#if not self.inDatabase(tree, filename):
-				if not self.entryExists(tree, filename):
-					sport = self.getSport(tree)
-					gpxfile = "%s/garmintools-%d.gpx" % (self.tmpdir, len(importfiles))					
-					self.createGPXfile(gpxfile, tree)
-					importfiles.append((gpxfile, sport))
-				else:
-					logging.debug("%s already present. Skipping import." % (filename,) )
+				try:
+					tree = etree.parse(fileString)
+					#if not self.inDatabase(tree, filename):
+					if not self.entryExists(tree, filename):
+						sport = self.getSport(tree)
+						gpxfile = "%s/garmintools-%d.gpx" % (self.tmpdir, len(importfiles))
+						self.createGPXfile(gpxfile, tree)
+						importfiles.append((gpxfile, sport))
+					else:
+						logging.debug("%s already present. Skipping import." % (filename,) )
+				except:
+					logging.error('Error parsing entry '+ str(filename))
+					traceback.print_exc()
 			else:
 				logging.error("File %s failed validation" % (filename))
 		logging.debug("<<")
@@ -207,7 +214,7 @@ class garmintools_full():
 			stringStartDate = stringStartUTC[0:10]
 			for entry in listStringStartUTC:
 				#logging.debug("start: "+str(startDatetime)+" | entry: "+str(entry)+" | gap: "+str(datetimePlusDelta))
-				if entry[0] is not None:		
+				if entry[0] is not None:
 					if str(entry[0]).startswith(stringStartDate):
 						deltaGap = timedelta(seconds=gap)
 						datetimeStartUTC = datetime.strptime(stringStartUTC,"%Y-%m-%dT%H:%M:%SZ")
@@ -219,7 +226,7 @@ class garmintools_full():
 							break
 		else:
 			if (stringStartUTC,) in listStringStartUTC: # strange way to store results from DB
-				found = True		
+				found = True
 		logging.debug("<<")
 		return found
 
@@ -251,7 +258,7 @@ class garmintools_full():
 		xslt_doc = etree.parse(self.data_path+"/translate.xsl")
 		transform = etree.XSLT(xslt_doc)
 		result_tree = transform(tree)
-		result_tree.write(gpxfile, xml_declaration=True)
+		result_tree.write(gpxfile, xml_declaration=True, encoding='UTF-8')
 
 	def dumpBinaries(self, listFiles):
 		logging.debug(">>")
