@@ -32,14 +32,14 @@ class About:
 		self.version = version
 
 	def run(self):
-		authors = ["Fiz Vázquez <vud1@sindominio.net>\nDavid García Granda <dgranda@gmail.com>\nJohn Blance <john.blance@gmail.com>\n\n-Package maintainers:\n\nRedHat/Fedora: Douglas E. Warner <silfreed@silfreed.net>\nDebian: Noèl Köthe <noel@debian.org>\nUbuntu: Kevin Dwyer <kevin@pheared.net>, Alessio Treglia <quadrispro@ubuntu.com>"]
-		translator_credits = "Basque: Jabier Santamaria <mendikote@gmail.com>\nCatalan: Eloi Crespillo Itchart <eloi@ikuszen.com>\nCzech: Lobus Pokorny <sp.pok@seznam.cz>\nFrench: Dj <dj@djremixtheblog.be>, Pierre Gaigé <pgaige@free.fr>\nNorwegian: Havard Davidsen <havard.davidsen@gmail.com>\nPolish: Seweryn Kokot <skokot@po.opole.pl>\nGerman: Aleks <aleks@schnecklecker.de>, Noèl Köthe <noel@debian.org>\nSpanish: Fiz Vázquez <vud1@sindominio.net>, David García Granda <dgranda@gmail.com>"
-		license = "PyTrainer - The free sport tracking center\nCopyright (C) 2005-10 Fiz Vázquez\n\nThis program is free software; you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 2 of the License, or\n(at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA"
+		authors = ["Fiz Vázquez <vud1@sindominio.net>\nDavid García Granda <dgranda@gmail.com>\nJohn Blance <john.blance@gmail.com>\nArnd Zapletal <a.zapletal@gmail.com>\nNathan Jones <nathan@ncjones.com>\n\n-Package maintainers:\n\nRedHat/Fedora: Douglas E. Warner <silfreed@silfreed.net>\nDebian: Noèl Köthe <noel@debian.org>\nUbuntu: Kevin Dwyer <kevin@pheared.net>, Alessio Treglia <quadrispro@ubuntu.com>"]
+		translator_credits = "Euskara: Jabier Santamaria <mendikote@gmail.com>\nCatalà: Eloi Crespillo Itchart <eloi@ikuszen.com>\nČesky: Lobus Pokorny <sp.pok@seznam.cz>\nFrançais: Dj <dj@djremixtheblog.be>, Pierre Gaigé <pgaige@free.fr>\nNorsk: Havard Davidsen <havard.davidsen@gmail.com>\nPolski: Seweryn Kokot <skokot@po.opole.pl>\nDeutsch: Aleks <aleks@schnecklecker.de>, Noèl Köthe <noel@debian.org>\nEspañol: Fiz Vázquez <vud1@sindominio.net>, David García Granda <dgranda@gmail.com>"
+		license = "PyTrainer - The free sport tracking center\nCopyright (C) 2005-09 Fiz Vázquez\n\nThis program is free software; you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation; either version 2 of the License, or\n(at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA"
 		about_dialog = gtk.AboutDialog()
 		about_dialog.set_destroy_with_parent(True)
 		about_dialog.set_name("pyTrainer")
 		about_dialog.set_version(self.version)
-		about_dialog.set_copyright("Copyright \xc2\xa9 2005-10 Fiz Vázquez")
+		about_dialog.set_copyright("Copyright \xc2\xa9 2005-09 Fiz Vázquez")
 		about_dialog.set_website("http://sourceforge.net/projects/pytrainer")
 		about_dialog.set_website_label("http://sourceforge.net/projects/pytrainer")
 		about_dialog.set_comments("The free sport tracking center")
