@@ -26,37 +26,31 @@ from gui.windowrecord import WindowRecord
 from gui.dialogselecttrack import DialogSelectTrack
 from lib.ddbb import DDBB
 from lib.xmlUtils import XMLParser
-from lib.system import checkConf
 from lib.date import Date
 from lib.gpx import Gpx
+from pytrainer.equipment import EquipmentService
 
 class Record:
 	def __init__(self, data_path = None, parent = None):
-		logging.debug('>>') 
+		logging.debug('>>')
 		self.parent = parent
+		self.pytrainer_main = parent
+		self._equipment_service = EquipmentService(self.pytrainer_main.ddbb)
 		self.data_path = data_path
 		logging.debug('setting date...')
 		self.date = Date()
-		logging.debug('Checking current configuration...')
-		self.conf = checkConf()									#TODO change to reference main versions of these
-		self.filename = self.conf.getValue("conffile")			#
-		logging.debug('Retrieving data from '+ self.filename)	#
-		self.configuration = XMLParser(self.filename)			#
-		self.ddbb = DDBB(self.configuration)					#
-		logging.debug('connecting to DDBB')						#
-		self.ddbb.connect()										#
 		logging.debug('<<')
 
 	def newRecord(self, list_sport, date, title=None, distance=None, time=None, upositive=None, unegative=None, bpm=None, calories=None, comment=None):
 		logging.debug('>>')
-		self.recordwindow = WindowRecord(self.data_path, list_sport,self, date, title, distance, time, upositive, unegative, bpm, calories, comment)
+		self.recordwindow = WindowRecord(self._equipment_service, self.data_path, list_sport,self, date, title, distance, time, upositive, unegative, bpm, calories, comment)
 		self.recordwindow.run()
 		logging.debug('<<')
-		
+
 	def newMultiRecord(self, activities, list_sport):
 		logging.debug('>>')
 		#activities (activity_id, start_time, distance, duration, sport, gpx_file)
-		self.recordwindow = WindowRecord(self.data_path, list_sport, parent=self, windowTitle="Modify details before importing")
+		self.recordwindow = WindowRecord(self._equipment_service, self._equipment_service, self.data_path, list_sport, parent=self, windowTitle="Modify details before importing")
 		self.recordwindow.populateMultiWindow(activities)
 		self.recordwindow.run()
 		return self.recordwindow.getActivityData()
@@ -64,10 +58,14 @@ class Record:
 
 	def editRecord(self,id_record,list_sport):
 		logging.debug('>>')
-		#record = self.ddbb.select("records", "*", "id_record=\"%s\"" %id_record)
-		record = self.ddbb.select("records", "id_record, date, sport, distance, time, beats, average, calories, comments, gpslog, title, upositive, unegative, maxspeed, maxpace, pace, maxbeats, date_time_utc, date_time_local", "id_record=\"%s\"" %id_record)
+		activity = self.pytrainer_main.activitypool.get_activity(id_record)
+		record_equipment = self.get_record_equipment(id_record)
+		self.recordwindow = WindowRecord(self._equipment_service, self.data_path, list_sport, self, None, windowTitle=_("Edit Entry"), equipment=record_equipment)
+		self.recordwindow.setValuesFromActivity(activity)
+		'''
+		record = self.pytrainer_main.ddbb.select("records", "id_record, date, sport, distance, time, beats, average, calories, comments, gpslog, title, upositive, unegative, maxspeed, maxpace, pace, maxbeats, date_time_utc, date_time_local", "id_record=\"%s\"" %id_record)
 		logging.debug('retrieving data from DB: '+str(record))
-		gpxfile = self.conf.getValue("gpxdir")+"/%d.gpx"%int(id_record)
+		gpxfile = self.pytrainer_main.profile.gpxdir+"/%d.gpx"%int(id_record)
 		logging.debug('gpx file associated: '+gpxfile)
 		self.recordwindow = WindowRecord(self.data_path, list_sport,self, None, windowTitle=_("Edit Entry"))
 		if os.path.isfile(gpxfile):
@@ -76,16 +74,17 @@ class Record:
 			self.recordwindow.frameVelocity.set_sensitive(0)	#Greying out options to indicate this to user
 		logging.debug('sending record info to window')
 		self.recordwindow.setValues(record[0])
+		'''
 		logging.debug('launching window')
 		self.recordwindow.run()
 		logging.debug('<<')
-	
+
 	def removeRecord(self,id_record):
 		logging.debug('>>')
-		record = self.ddbb.delete("records", "id_record=\"%s\"" %id_record)
-		laps = self.ddbb.delete("laps", "record=\"%s\"" %id_record)
+		record = self.pytrainer_main.ddbb.delete("records", "id_record=\"%s\"" %id_record)
+		laps = self.pytrainer_main.ddbb.delete("laps", "record=\"%s\"" %id_record)
 		logging.debug('removed record '+str(id_record)+' (and associated laps) from DB')
-		gpxfile = self.conf.getValue("gpxdir")+"/%d.gpx"%int(id_record)
+		gpxfile = self.pytrainer_main.profile.gpxdir+"/%d.gpx"%int(id_record)
 		if os.path.isfile(gpxfile):
 			os.remove(gpxfile)
 			logging.debug('removed gpxfile '+gpxfile)
@@ -98,9 +97,9 @@ class Record:
 		cells= "date,sport,distance,time,beats,comments,average,calories,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats"
 		if (list_options["rcd_beats"] == ""):
 			list_options["rcd_beats"] = 0
-		
+
 		#calculate the sport id
-		sport_id = self.ddbb.select("sports","id_sports","name=\"%s\"" %list_options["rcd_sport"])[0][0]
+		sport_id = self.pytrainer_main.ddbb.select("sports","id_sports","name=\"%s\"" %list_options["rcd_sport"])[0][0]
 
 		values= (
 			list_options["rcd_date"],
@@ -115,13 +114,31 @@ class Record:
 			self.parseFloatRecord(list_options["rcd_upositive"]),
 			self.parseFloatRecord(list_options["rcd_unegative"]),
 			self.parseFloatRecord(list_options["rcd_maxvel"]),
-			self.parseFloatRecord(list_options["rcd_maxpace"]),
-			self.parseFloatRecord(list_options["rcd_pace"]),
+			self.pace_to_float(list_options["rcd_maxpace"]),
+			self.pace_to_float(list_options["rcd_pace"]),
 			self.parseFloatRecord(list_options["rcd_maxbeats"])
 			)
 		logging.debug('<<')
 		return cells,values
-		
+
+	def pace_to_float(self, value):
+		'''Take a mm:ss or mm.ss and return float'''
+		value = value.replace(':', '.')
+		try:
+			value = float(value)
+		except ValueError:
+			value = None
+		return value
+
+	def pace_from_float(self, value):
+		'''Helper to generate mm:ss from float representation mm.ss (or mm,ss?)'''
+		#Check that value supplied is a float
+		try:
+			_value = "%0.2f" % float(value)
+		except ValueError:
+			_value = str(value)
+		return _value.replace('.',':')
+
 	def _formatRecordNew (self, list_options):
 		"""20.07.2008 - dgranda
 		New records handle date_time_utc field which is transparent when updating, so logic method has been splitted
@@ -130,10 +147,10 @@ class Record:
 		logging.debug('>>')
 		time = self.date.time2second(list_options["rcd_time"])
 		average = self.parseFloatRecord(list_options["rcd_average"])
-		keys= "date,sport,distance,time,beats,comments,average,calories,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats,date_time_utc,date_time_local"
+		keys= "date,sport,distance,time,beats,comments,average,calories,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats,date_time_utc,date_time_local, duration"
 		if (list_options["rcd_beats"] == ""):
 			list_options["rcd_beats"] = 0
-		
+
 		#retrieving sport id (adding sport if it doesn't exist yet)
 		sport_id = self.getSportId(list_options["rcd_sport"],add=True)
 
@@ -150,16 +167,17 @@ class Record:
 			self.parseFloatRecord(list_options["rcd_upositive"]),
 			self.parseFloatRecord(list_options["rcd_unegative"]),
 			self.parseFloatRecord(list_options["rcd_maxvel"]),
-			self.parseFloatRecord(list_options["rcd_maxpace"]),
-			self.parseFloatRecord(list_options["rcd_pace"]),
+			self.pace_to_float(list_options["rcd_maxpace"]),
+			self.pace_to_float(list_options["rcd_pace"]),
 			self.parseFloatRecord(list_options["rcd_maxbeats"]),
 			list_options["date_time_utc"],
 			list_options["date_time_local"],
+			time,
 			)
 		logging.debug('<<')
 		return keys,values
 
-	def insertRecord(self, list_options, laps=None):
+	def insertRecord(self, list_options, laps=None, equipment=None):
 		logging.debug('>>')
 		#Create entry for activity in records table
 		if list_options is None:
@@ -167,9 +185,9 @@ class Record:
 			return None
 		logging.debug('list_options: '+str(list_options))
 		cells,values = self._formatRecordNew(list_options)
-		self.ddbb.insert("records",cells,values)
+		self.pytrainer_main.ddbb.insert("records",cells,values)
 		logging.debug('DB updated: '+str(cells)+' | '+str(values))
-		id_record = self.ddbb.lastRecord("records")
+		id_record = self.pytrainer_main.ddbb.lastRecord("records")
 		#Create entry(s) for activity in laps table
 		if laps is not None:
 			for lap in laps:
@@ -177,16 +195,22 @@ class Record:
 				lap_keys = ", ".join(map(str, lap.keys()))
 				lap_values = lap.values()
 				self.insertLaps(lap_keys,lap.values())
+		if equipment is not None:
+			for equipment_id in equipment:
+				self._insert_record_equipment(id_record, equipment_id)
 		gpxOrig = list_options["rcd_gpxfile"]
 		if os.path.isfile(gpxOrig):
-			gpxDest = self.conf.getValue("gpxdir")
+			gpxDest = self.pytrainer_main.profile.gpxdir
 			gpxNew = gpxDest+"/%d.gpx"%id_record
-			shutil.move(gpxOrig, gpxNew)
-			logging.debug('Moving '+gpxOrig+' to '+gpxNew)
+			#Leave original file in place...
+			#shutil.move(gpxOrig, gpxNew)
+			#logging.debug('Moving '+gpxOrig+' to '+gpxNew)
+			shutil.copy(gpxOrig, gpxNew)
+			logging.debug('Copying '+gpxOrig+' to '+gpxNew)
 		#self.parent.refreshListRecords()
 		logging.debug('<<')
-		return self.ddbb.lastRecord("records")
-		
+		return self.pytrainer_main.ddbb.lastRecord("records")
+
 	def insertNewRecord(self, gpxOrig, entry): #TODO consolidate with insertRecord
 		"""29.03.2008 - dgranda
 		Moves GPX file to store destination and updates database
@@ -196,11 +220,11 @@ class Record:
 		if list_options is None:
 			return None
 		return self.insertRecord(list_options, laps=gpx_laps)
-	
+
 	def lapsFromGPX(self, gpx):
 		logging.debug('>>')
 		laps = []
-		gpxLaps = gpx.getLaps() 
+		gpxLaps = gpx.getLaps()
 		for lap in gpxLaps:
 			lap_number = gpxLaps.index(lap)
 			tmp_lap = {}
@@ -216,12 +240,12 @@ class Record:
 			laps.append(tmp_lap)
 		logging.debug('<<')
 		return laps
-			
+
 	def summaryFromGPX(self, gpxOrig, entry):
 		"""29.03.2008 - dgranda
 		Retrieves info which will be stored in DB from GPX file
 		args: path to source GPX file
-		returns: list with fields and values, list of laps 
+		returns: list with fields and values, list of laps
 		"""
 		logging.debug('>>')
 		gpx = Gpx(self.data_path,gpxOrig)
@@ -244,7 +268,7 @@ class Record:
 		summaryRecord['rcd_comments'] = ''
 		summaryRecord['rcd_title'] = ''
 		summaryRecord['rcd_time'] = time_hhmmss #ToDo: makes no sense to work with arrays
-		summaryRecord['rcd_distance'] = "%0.2f" %distance 
+		summaryRecord['rcd_distance'] = "%0.2f" %distance
 		if speed == 0:
 			summaryRecord['rcd_pace'] = "0"
 		else:
@@ -270,9 +294,11 @@ class Record:
 		logging.debug('<<')
 		return summaryRecord, laps
 
-	def updateRecord(self, list_options, id_record):
+	def updateRecord(self, list_options, id_record, equipment=None):
 		logging.debug('>>')
-		gpxfile = self.conf.getValue("gpxdir")+"/%d.gpx"%int(id_record)
+		#Remove activity from pool so data is updated
+		self.pytrainer_main.activitypool.remove_activity(id_record)
+		gpxfile = self.pytrainer_main.profile.gpxdir+"/%d.gpx"%int(id_record)
 		gpxOrig = list_options["rcd_gpxfile"]
 		if os.path.isfile(gpxOrig):
 			if gpxfile != gpxOrig:
@@ -282,8 +308,10 @@ class Record:
 				logging.debug('removing gpxfile') # ein?
 				logging.debug('updating bbdd') #ein?
 		cells,values = self._formatRecord(list_options)
-		self.ddbb.update("records",cells,values," id_record=%d" %int(id_record))
-		self.parent.refreshListView()
+		self.pytrainer_main.ddbb.update("records",cells,values," id_record=%d" %int(id_record))
+		if equipment is not None:
+			self._update_record_equipment(id_record, equipment)
+		self.pytrainer_main.refreshListView()
 		logging.debug('<<')
 
 	def parseFloatRecord(self,string):
@@ -295,27 +323,35 @@ class Record:
 				return float(string)
 		else:
 			return 0
-				
+
 	def getrecordInfo(self,id_record):
 		logging.debug('--')
-		return self.ddbb.select("records,sports",
+		if id_record is None or id_record == "":
+			return []
+		return self.pytrainer_main.ddbb.select("records,sports",
 					"sports.name,date,distance,time,beats,comments,average,calories,id_record,title,upositive,unegative,maxspeed,maxpace,pace,maxbeats,date_time_utc,date_time_local",
 					"id_record=\"%s\" and records.sport=sports.id_sports" %id_record)
-	
-	def getrecordList(self,date):
+
+	def getrecordList(self,date, id_sport=None):
 		logging.debug('--')
-		return self.ddbb.select("records,sports",
+		if not id_sport:
+			return self.pytrainer_main.ddbb.select("records,sports",
 					"sports.name,date,distance,time,beats,comments,average,calories,id_record,maxspeed,maxbeats,date_time_utc,date_time_local",
 					"date=\"%s\" and records.sport=sports.id_sports" %date)
+		else:
+			return self.pytrainer_main.ddbb.select("records,sports",
+					"sports.name,date,distance,time,beats,comments,average,calories,id_record,maxspeed,maxbeats,date_time_utc,date_time_local",
+					"date=\"%s\" and sports.id_sports=\"%s\" and records.sport=sports.id_sports" %(date,id_sport))
 
 	def getLaps(self, id_record):
 		logging.debug('--')
-		laps = self.ddbb.select("laps", 
+		laps = self.pytrainer_main.ddbb.select("laps",
 					"id_lap, record, elapsed_time, distance, start_lat, start_lon, end_lat, end_lon, calories, lap_number",
 					"record=\"%s\"" % id_record)
 		if laps is None or laps == []:  #No laps stored - update DB
 			logging.debug("No laps in DB for record %d" % id_record)
-			gpx_dest = self.conf.getValue("gpxdir")
+			#print ("No laps in DB for record %d" % id_record)
+			gpx_dest = self.pytrainer_main.profile.gpxdir
 			gpxfile = gpx_dest+"/%d.gpx"%id_record
 			gpx = Gpx(self.data_path,gpxfile)
 			laps = self.lapsFromGPX(gpx)
@@ -325,60 +361,77 @@ class Record:
 					lap_keys = ", ".join(map(str, lap.keys()))
 					lap_values = lap.values()
 					self.insertLaps(lap_keys,lap.values())
-			#Try to get lap info again #TODO? refactor				
-			laps = self.ddbb.select("laps", 
+			#Try to get lap info again #TODO? refactor
+			laps = self.pytrainer_main.ddbb.select("laps",
 					"id_lap, record, elapsed_time, distance, start_lat, start_lon, end_lat, end_lon, calories, lap_number",
 					"record=\"%s\"" % id_record)
-		return laps 
-					
+		return laps
+
 	def insertLaps(self, cells, values):
 		logging.debug('--')
 		logging.debug("Adding lap information: " + ", ".join(map(str, values)))
-		self.ddbb.insert("laps",cells,values)
+		self.pytrainer_main.ddbb.insert("laps",cells,values)
 		
+	def _insert_record_equipment(self, record_id, equipment_id):
+		self.pytrainer_main.ddbb.insert("record_equipment", "record_id, equipment_id", [record_id, equipment_id])
+		
+	def _update_record_equipment(self, record_id, equipment_ids):
+		self.pytrainer_main.ddbb.delete("record_equipment", "record_id={0}".format(record_id))
+		for id in equipment_ids:
+			self._insert_record_equipment(record_id, id)
+			
+	def get_record_equipment(self, record_id):
+		record_equipment = []
+		results = self.pytrainer_main.ddbb.select("record_equipment", "equipment_id", "record_id={0}".format(record_id))
+		for row in results:
+			id = row[0]
+			equipment_item = self._equipment_service.get_equipment_item(id)
+			record_equipment.append(equipment_item)
+		return record_equipment
+
 	def getrecordPeriod(self,date_ini, date_end, sport=None):
 		#TODO This is essentially the same as getrecordPeriodSport (except date ranges) - need to look at merging the two
 		tables = "records,sports"
 		if not sport:
 			condition = "date>=\"%s\" and date<=\"%s\" and records.sport=sports.id_sports" %(date_ini,date_end)
 		else:
-			condition = "date>=\"%s\" and date<=\"%s\" and records.sport=sports.id_sports and sports.name=\"%s\"" %(date_ini,date_end, sport)
-	
-		return self.ddbb.select(tables,"date,distance,time,beats,comments,average,calories,maxspeed,maxbeats, sports.name", condition)
-	
+			condition = "date>=\"%s\" and date<=\"%s\" and records.sport=sports.id_sports and sports.id_sports=\"%s\"" %(date_ini,date_end, sport)
+
+		return self.pytrainer_main.ddbb.select(tables,"date,distance,time,beats,comments,average,calories,maxspeed,maxbeats, sports.name", condition)
+
 	def getrecordPeriodSport(self,date_ini, date_end,sport):
 		if not sport:
 			tables = "records"
 			condition = "date>\"%s\" and date<\"%s\"" %(date_ini,date_end)
 		else :
 			tables = "records,sports"
-			condition = "date>\"%s\" and date<\"%s\" and records.sport=sports.id_sports and sports.name=\"%s\"" %(date_ini,date_end,sport)
-		
-		return self.ddbb.select(tables,
+			condition = "date>\"%s\" and date<\"%s\" and records.sport=sports.id_sports and sports.id_sports=\"%s\"" %(date_ini,date_end,sport)
+
+		return self.pytrainer_main.ddbb.select(tables,
 					"date,distance,time,beats,comments,average,calories,maxspeed,maxbeats",
 					condition)
 
 	def getSportMet(self,sport):
 		logging.debug('--')
-		return self.ddbb.select("sports","met","name=\"%s\"" %(sport))[0][0]
-	
+		return self.pytrainer_main.ddbb.select("sports","met","name=\"%s\"" %(sport))[0][0]
+
 	def getSportWeight(self,sport):
 		logging.debug('--')
-		return self.ddbb.select("sports","weight","name=\"%s\"" %(sport))[0][0]
-		
+		return self.pytrainer_main.ddbb.select("sports","weight","name=\"%s\"" %(sport))[0][0]
+
 	def getSportId(self,sport,add=None):
 		"""31.08.2008 - dgranda
 		Retrieves id_sports from provided sport. If add is not set to None, sport is added to the system
 		arguments:
-			sport: sport's name to get id from 
+			sport: sport's name to get id from
 			add: attribute to add or not the sport to db
 		returns: id_sports from provided sport"""
 		logging.debug('>>')
-		sport_id=1
+		sport_id=None
 		if sport == "" or sport is None:
 			return sport_id
 		try:
-			sport_id = self.ddbb.select("sports","id_sports","name=\"%s\"" %(sport))[0][0]
+			sport_id = self.pytrainer_main.ddbb.select("sports","id_sports","name=\"%s\"" %(sport))[0][0]
 		except:
 			logging.error('Error retrieving id_sports from '+ str(sport))
 			#traceback.print_last()
@@ -389,45 +442,52 @@ class Record:
 				sport_id = self.addNewSport(sport,"0","0")
 		logging.debug('<<')
 		return sport_id
-	
+
 	def addNewSport(self,sport,met,weight):
 		"""31.08.2008 - dgranda
 		Copied from Profile class, adds a new sport.
 		arguments:
-			sport: sport's name 
+			sport: sport's name
 			met:
 			weight:
 		returns: id_sports from new sport"""
 		logging.debug(">>")
 		logging.debug("Adding new sport: "+sport+"|"+weight+"|"+met)
 		sportT = [sport,met,weight]
-		self.ddbb.insert("sports","name,met,weight",sportT)
-		sport_id = self.ddbb.select("sports","id_sports","name=\"%s\"" %(sport))[0][0]
+		self.pytrainer_main.ddbb.insert("sports","name,met,weight",sportT)
+		sport_id = self.pytrainer_main.ddbb.select("sports","id_sports","name=\"%s\"" %(sport))[0][0]
 		logging.debug("<<")
 		return sport_id
-	
+
 	def getAllrecord(self):
 		logging.debug('--')
-		return self.ddbb.select("records", "date,distance,time,beats,comments,average,calories")
-	
+		return self.pytrainer_main.ddbb.select("records", "date,distance,time,beats,comments,average,calories")
+
 	def getAllRecordList(self):
 		logging.debug('--')
-		return self.ddbb.select("records,sports", 
+		return self.pytrainer_main.ddbb.select("records,sports",
 			"date,distance,average,title,sports.name,id_record,time,beats,calories",
 			"sports.id_sports = records.sport order by date desc")
-	
+
 	def getRecordListByCondition(self,condition):
 		logging.debug('--')
-		return self.ddbb.select("records,sports", 
-			"date,distance,average,title,sports.name,id_record,time,beats,calories",
-			"sports.id_sports = records.sport and %s" %condition)
+		if condition is None:
+			return self.getAllRecordList()
+		else:
+			logging.debug("condition: %s" % condition)
+			return self.pytrainer_main.ddbb.select("records,sports",
+				"date,distance,average,title,sports.name,id_record,time,beats,calories",
+				"sports.id_sports = records.sport and %s order by date desc" %condition)
 
-	def getRecordDayList(self,date):
+	def getRecordDayList(self,date, id_sport=None):
 		logging.debug('>>')
 		year,month,day = date.split("-")
 		logging.debug('Retrieving data for '+year+'.'+month+'.'+day)
 		# Why is looking for all days of the same month?
-		records = self.ddbb.select("records","date","date LIKE '"+year+"-"+month+"-%'")
+		if not id_sport:
+			records = self.pytrainer_main.ddbb.select("records","date","date LIKE '"+year+"-"+month+"-%'")
+		else:
+			records = self.pytrainer_main.ddbb.select("records","date","date LIKE \"%s-%s-%%\" and sport=\"%s\"" %(year,month,id_sport))
 		logging.debug('Found '+str(len(records))+' entries')
 		day_list = []
 		for i in records:
@@ -436,7 +496,7 @@ class Record:
 			day_list.append(record[2])
 		logging.debug('<<')
 		return day_list
-		
+
 	def actualize_fromgpx(self,gpxfile): #TODO remove? - should never have multiple tracks per GPX file
 		logging.debug('>>')
 		logging.debug('loading file: '+gpxfile)
@@ -464,7 +524,7 @@ class Record:
 		heartrate = gpx.getHeartRateAverage()
 		date = gpx.getDate()
 		calories = gpx.getCalories()
-		
+
 		self.recordwindow.rcd_date.set_text(date)
 		self.recordwindow.rcd_upositive.set_text(str(upositive))
 		self.recordwindow.rcd_unegative.set_text(str(unegative))
@@ -479,7 +539,7 @@ class Record:
 		self.recordwindow.on_calccalories_clicked(None)
 		self.recordwindow.rcd_maxpace.set_text("%d.%02d" %((3600/maxspeed)/60,(3600/maxspeed)%60))
 		logging.debug('<<')
-	
+
 	def __actualize_fromgpx(self, gpxfile, name=None):
 		logging.debug('>>')
 		gpx = Gpx(self.data_path,gpxfile,name)
@@ -493,11 +553,11 @@ class Record:
 		logging.debug('Launching window...')
 		selectrckdialog.run()
 		logging.debug('<<')
-		
+
 	def newGpxRecord(self,gpxfile,list_sport): #TODO Not used?
 		logging.debug('>>')
 		logging.debug("opening a new window record "+self.data_path+'|'+gpxfile+'|'+str(list_sport))
-		self.recordwindow = WindowRecord(self.data_path, list_sport,self, None)
+		self.recordwindow = WindowRecord(self._equipment_service, self.data_path, list_sport,self, None)
 		logging.debug('setting text in window '+ gpxfile)
 		self.recordwindow.rcd_gpxfile.set_text(gpxfile)
 		logging.debug('retrieving data from gpx file')
@@ -509,7 +569,7 @@ class Record:
 	def importFromGPX(self, gpxFile, sport):
 		"""
 		Add a record from a valid pytrainer type GPX file
-		"""	
+		"""
 		logging.debug('>>')
 		entry_id = None
 		if not os.path.isfile(gpxFile):
@@ -526,128 +586,3 @@ class Record:
 				logging.info("Entry %d has been added" % entry_id)
 		logging.debug('<<')
 		return entry_id
-
-	#def importFromGTRNCTR(self,gtrnctrFile): #TODO remove
-		"""22.03.2008 - dgranda
-		Retrieves sport, date and start time from each entry coming from GPS
-		and compares with what is stored locally, just to import new entries
-		31.08.2008 - dgranda - Only checks start time, discarding sport info
-		args: file with data from GPS file (garmin format)
-		returns: none"""
-		"""
-		logging.debug('>>')
-		logging.info('Retrieving data from '+gtrnctrFile)
-		xmlParser=XMLParser(gtrnctrFile)
-		listTracksGPS = xmlParser.shortFromGPS(gtrnctrFile, True)
-		logging.info('GPS: '+str(len(listTracksGPS))+' entries found')
-		if len(listTracksGPS)>0:
-			listTracksLocal = self.shortFromLocalDB(True)
-			logging.info('Local: '+str(len(listTracksLocal))+' entries found')
-			listNewTracks=self.compareTracks(listTracksGPS,listTracksLocal,False)
-			newTracks = len(listNewTracks)
-			# empty constructor for Gpx 
-			gpx = Gpx()
-			i=0
-			for entry in listNewTracks:
-				i=i+1
-				logging.debug('Entry summary to import: '+str(entry))
-				newGPX=gpx.retrieveDataFromGTRNCTR(gtrnctrFile, entry)
-				entry_id = self.insertNewRecord(newGPX, entry)
-				logging.info('Entry '+str(entry_id)+' has been added ('+str(i)+'/'+str(newTracks)+')')
-		else:
-			logging.info('No tracks found in GPS device')
-		logging.debug('<<')
-		"""
-		
-	#def shortFromLocal(self): #TODO remove
-		"""25.03.2008 - dgranda
-		Retrieves sport, date and start time from each entry stored locally
-		12.07.2008 - dgranda - Added id_record for each one
-		returns: list with lists: SPORT|DATE_START_TIME|ID_RECORD
-		31.08.2008 - dgranda - Only available due to migration purposes from Main class"""
-		'''logging.debug('>>')
-		listTracksGPX = []
-		sport = "Run" #hardcoded - 25.03.2008 (no info stored in gpx files yet)
-		# looking in configuration for storing directory
-		gpxDir = self.conf.getValue("gpxdir")
-		# retrieving how many files are there
-		for gpxFile in os.listdir(gpxDir):
-			#logging.debug('File: '+gpxFile)
-			gpx = Gpx()
-			date_time = gpx.getStartTimeFromGPX(gpxDir+"/"+gpxFile)[0]
-			if date_time != 0:
-				logging.debug('File: '+gpxFile+' | Date: '+date_time)
-				id_record = gpxFile.partition('.')[0]
-				listTracksGPX.append((sport,date_time,id_record))
-			else:
-				logging.error('Skipping '+gpxFile+' because of wrong format')
-		logging.debug('<<')
-		return listTracksGPX'''
-		
-	#def shortFromLocalDB(self, getSport=True): #TODO remove
-		"""12.07.2008 - dgranda
-		Retrieves sport, date and start time from local database
-		returns: list with lists: SPORT|DATE_START_TIME"""
-		'''logging.debug('>>')
-		# Retrieving sport (optional) and date_time (UTC) for each entry in DB
-		# ToDo: replace id_sports with name
-		listTracksGPX = self.ddbb.shortFromLocal(getSport)
-		# There is an issue when retrieving data without sport info:
-		# record|shortFromLocalDB|Retrieved info: [(None,), (u'2008-01-15T11:35:50Z',), (u'2008-01-16T11:05:53Z',)...
-		# ToDo: check sqliteUtils.freeExec(self,sql)
-		# Just a dirty workaround to make comparison work
-		if getSport is not True:
-			tempList = []
-			for entry in listTracksGPX:
-				tempList.append(entry[0])
-			listTracksGPX = tempList
-		logging.debug('Retrieved info: '+str(listTracksGPX))
-		logging.debug('<<')
-		return listTracksGPX'''
-		
-	#def removeSportFromList(self, list1): #TODO remove
-		'''resultList = []
-		for entry in list1:
-			resultList.append(entry[1])
-		return resultList'''
-		
-	#def compareLists(self,list1,list2): #TODO remove
-		'''# Optimizing comparison - 26042008
-		# http://mail.python.org/pipermail/python-list/2002-May/141458.html
-		tempDict = dict(zip(list1,list1))
-		return [x for x in list2 if x not in tempDict]'''
-		
-	#def compareTracks(self,listTracksGPS,listTracksLocal,checkSport=True): #TODO remove
-		"""22.03.2008 - dgranda
-		Compares tracks retrieved from GPS with already locally stored
-		args:
-			listTracksGPS: gps track list with lists -> (SPORT)|DATE_START_TIME
-			listTracksLocal: local track list with lists -> (SPORT)|DATE_START_TIME
-			checkSport (02.09.2008): indicates if sport data is included when comparing 
-		returns: tracks which are not present locally (list with lists)"""
-		'''logging.debug('>>')
-		if checkSport is True:
-			logging.info('Comparing sport info')
-			listGPS = listTracksGPS[:]
-			listLocal = listTracksLocal[:]
-		else:
-			logging.info('Discarding sport info')
-			listGPS = self.removeSportFromList(listTracksGPS)
-			listLocal = self.removeSportFromList(listTracksLocal)
-		
-		resultList = self.compareLists(listLocal,listGPS)
-		
-		if len(resultList)>0 and checkSport is not True: # sport info is added to resultList
-			tempList = []
-			for entry in resultList:
-				for x in listTracksGPS:
-					if x[1] is entry:
-						tempList.append(x)
-						break
-			resultList = tempList[:]
-		
-		logging.info('Tracks to be imported: '+str(len(resultList)))
-		logging.debug('Tracks summary: '+str(resultList))
-		logging.debug('<<')
-		return resultList '''
-		
